@@ -58,11 +58,7 @@
     NativeModule.require('internal/trace_events_async_hooks').setup();
     NativeModule.require('internal/inspector_async_hook').setup();
 
-    // Do not initialize channel in debugger agent, it deletes env variable
-    // and the main thread won't see it.
-    if (process.argv[1] !== '--debug-agent')
-      _process.setupChannel();
-
+    _process.setupChannel();
     _process.setupRawDebug();
 
     const browserGlobals = !process._noBrowserGlobals;
@@ -75,6 +71,13 @@
     // URL::ToObject() method is used.
     NativeModule.require('internal/url');
 
+    // On OpenBSD process.execPath will be relative unless we
+    // get the full path before process.execPath is used.
+    if (process.platform === 'openbsd') {
+      const { realpathSync } = NativeModule.require('fs');
+      process.execPath = realpathSync.native(process.execPath);
+    }
+
     Object.defineProperty(process, 'argv0', {
       enumerable: true,
       configurable: false,
@@ -175,7 +178,7 @@
           const fs = NativeModule.require('fs');
           // read the source
           const filename = Module._resolveFilename(process.argv[1]);
-          var source = fs.readFileSync(filename, 'utf-8');
+          const source = fs.readFileSync(filename, 'utf-8');
           checkScriptSyntax(source, filename);
           process.exit(0);
         }
@@ -221,7 +224,7 @@
           // Read all of stdin - execute it.
           process.stdin.setEncoding('utf8');
 
-          var code = '';
+          let code = '';
           process.stdin.on('data', function(d) {
             code += d;
           });
@@ -415,7 +418,7 @@
     const versionTypes = icu.getVersion().split(',');
 
     for (var n = 0; n < versionTypes.length; n++) {
-      var name = versionTypes[n];
+      const name = versionTypes[n];
       const version = icu.getVersion(name);
       Object.defineProperty(process.versions, name, {
         writable: false,
@@ -583,7 +586,7 @@
   ];
 
   NativeModule.prototype.compile = function() {
-    var source = NativeModule.getSource(this.id);
+    let source = NativeModule.getSource(this.id);
     source = NativeModule.wrap(source);
 
     this.loading = true;
