@@ -370,16 +370,6 @@ function writeAfterFIN(chunk, encoding, cb) {
   }
 }
 
-Socket.prototype.read = function(n) {
-  if (n === 0)
-    return stream.Readable.prototype.read.call(this, n);
-
-  this.read = stream.Readable.prototype.read;
-  this._consuming = true;
-  return this.read(n);
-};
-
-
 // FIXME(joyeecheung): this method is neither documented nor tested
 Socket.prototype.listen = function() {
   debug('socket.listen');
@@ -767,13 +757,7 @@ Socket.prototype._writeGeneric = function(writev, data, encoding, cb) {
     // Retain chunks
     if (err === 0) req._chunks = chunks;
   } else {
-    var enc;
-    if (data instanceof Buffer) {
-      enc = 'buffer';
-    } else {
-      enc = encoding;
-    }
-    err = createWriteReq(req, this._handle, data, enc);
+    err = createWriteReq(req, this._handle, data, encoding);
   }
 
   if (err)
@@ -1141,7 +1125,9 @@ Socket.prototype.ref = function() {
     return this;
   }
 
-  this._handle.ref();
+  if (typeof this._handle.ref === 'function') {
+    this._handle.ref();
+  }
 
   return this;
 };
@@ -1153,7 +1139,9 @@ Socket.prototype.unref = function() {
     return this;
   }
 
-  this._handle.unref();
+  if (typeof this._handle.unref === 'function') {
+    this._handle.unref();
+  }
 
   return this;
 };
