@@ -1,5 +1,26 @@
+// Copyright Joyent, Inc. and other Node contributors.
+//
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the
+// "Software"), to deal in the Software without restriction, including
+// without limitation the rights to use, copy, modify, merge, publish,
+// distribute, sublicense, and/or sell copies of the Software, and to permit
+// persons to whom the Software is furnished to do so, subject to the
+// following conditions:
+//
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
+// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
+// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
+// USE OR OTHER DEALINGS IN THE SOFTWARE.
+
 'use strict';
-require('../common');
+const common = require('../common');
 const assert = require('assert');
 const fork = require('child_process').fork;
 const net = require('net');
@@ -19,7 +40,7 @@ ProgressTracker.prototype.check = function() {
 
 if (process.argv[2] === 'child') {
 
-  var serverScope;
+  let serverScope;
 
   process.on('message', function onServer(msg, server) {
     if (msg.what !== 'server') return;
@@ -29,13 +50,13 @@ if (process.argv[2] === 'child') {
 
     server.on('connection', function(socket) {
       console.log('CHILD: got connection');
-      process.send({what: 'connection'});
+      process.send({ what: 'connection' });
       socket.destroy();
     });
 
     // start making connection from parent
     console.log('CHILD: server listening');
-    process.send({what: 'listening'});
+    process.send({ what: 'listening' });
   });
 
   process.on('message', function onClose(msg) {
@@ -43,7 +64,7 @@ if (process.argv[2] === 'child') {
     process.removeListener('message', onClose);
 
     serverScope.on('close', function() {
-      process.send({what: 'close'});
+      process.send({ what: 'close' });
     });
     serverScope.close();
   });
@@ -55,33 +76,34 @@ if (process.argv[2] === 'child') {
     console.log('CHILD: got socket');
   });
 
-  process.send({what: 'ready'});
+  process.send({ what: 'ready' });
 } else {
 
-  var child = fork(process.argv[1], ['child']);
+  const child = fork(process.argv[1], ['child']);
 
-  child.on('exit', function() {
-    console.log('CHILD: died');
-  });
+  child.on('exit', common.mustCall(function(code, signal) {
+    const message = `CHILD: died with ${code}, ${signal}`;
+    assert.strictEqual(code, 0, message);
+  }));
 
   // send net.Server to child and test by connecting
-  var testServer = function(callback) {
+  function testServer(callback) {
 
     // destroy server execute callback when done
-    var progress = new ProgressTracker(2, function() {
+    const progress = new ProgressTracker(2, function() {
       server.on('close', function() {
         console.log('PARENT: server closed');
-        child.send({what: 'close'});
+        child.send({ what: 'close' });
       });
       server.close();
     });
 
     // we expect 4 connections and close events
-    var connections = new ProgressTracker(4, progress.done.bind(progress));
-    var closed = new ProgressTracker(4, progress.done.bind(progress));
+    const connections = new ProgressTracker(4, progress.done.bind(progress));
+    const closed = new ProgressTracker(4, progress.done.bind(progress));
 
     // create server and send it to child
-    var server = net.createServer();
+    const server = net.createServer();
     server.on('connection', function(socket) {
       console.log('PARENT: got connection');
       socket.destroy();
@@ -89,17 +111,17 @@ if (process.argv[2] === 'child') {
     });
     server.on('listening', function() {
       console.log('PARENT: server listening');
-      child.send({what: 'server'}, server);
+      child.send({ what: 'server' }, server);
     });
     server.listen(0);
 
     // handle client messages
-    var messageHandlers = function(msg) {
+    function messageHandlers(msg) {
 
       if (msg.what === 'listening') {
         // make connections
-        var socket;
-        for (var i = 0; i < 4; i++) {
+        let socket;
+        for (let i = 0; i < 4; i++) {
           socket = net.connect(server.address().port, function() {
             console.log('CLIENT: connected');
           });
@@ -116,22 +138,22 @@ if (process.argv[2] === 'child') {
         child.removeListener('message', messageHandlers);
         callback();
       }
-    };
+    }
 
     child.on('message', messageHandlers);
-  };
+  }
 
   // send net.Socket to child
-  var testSocket = function(callback) {
+  function testSocket(callback) {
 
     // create a new server and connect to it,
     // but the socket will be handled by the child
-    var server = net.createServer();
+    const server = net.createServer();
     server.on('connection', function(socket) {
       socket.on('close', function() {
         console.log('CLIENT: socket closed');
       });
-      child.send({what: 'socket'}, socket);
+      child.send({ what: 'socket' }, socket);
     });
     server.on('close', function() {
       console.log('PARENT: server closed');
@@ -145,23 +167,23 @@ if (process.argv[2] === 'child') {
     // will have to do.
     server.listen(0, function() {
       console.error('testSocket, listening');
-      var connect = net.connect(server.address().port);
-      var store = '';
+      const connect = net.connect(server.address().port);
+      let store = '';
       connect.on('data', function(chunk) {
         store += chunk;
         console.log('CLIENT: got data');
       });
       connect.on('close', function() {
         console.log('CLIENT: closed');
-        assert.equal(store, 'echo');
+        assert.strictEqual(store, 'echo');
         server.close();
       });
     });
-  };
+  }
 
   // create server and send it to child
-  var serverSuccess = false;
-  var socketSuccess = false;
+  let serverSuccess = false;
+  let socketSuccess = false;
   child.on('message', function onReady(msg) {
     if (msg.what !== 'ready') return;
     child.removeListener('message', onReady);
@@ -171,7 +193,6 @@ if (process.argv[2] === 'child') {
 
       testSocket(function() {
         socketSuccess = true;
-        child.kill();
       });
     });
 
